# NNSVS

[![][docs-latest-img]][docs-latest-url]
[![PyPI](https://img.shields.io/pypi/v/nnsvs.svg)](https://pypi.python.org/pypi/nnsvs)
[![License](http://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE)
[![arXiv](https://img.shields.io/badge/arXiv-2210.15987-b31b1b.svg)](https://arxiv.org/abs/2210.15987)
![Python CI](https://github.com/nnsvs/nnsvs/workflows/Python%20CI/badge.svg)
[![codecov](https://codecov.io/gh/nnsvs/nnsvs/branch/master/graph/badge.svg?token=Z66FDOQGH7)](https://codecov.io/gh/nnsvs/nnsvs)

[docs-latest-img]: https://img.shields.io/badge/docs-latest-blue.svg
[docs-latest-url]: https://nnsvs.github.io/nnsvs/

Neural network-based singing voice synthesis library for research

Documentation can be found at https://nnsvs.github.io.

## Citation

```
@article{yamamoto2022nnsvs,
  title={NNSVS: A Neural Network-Based Singing Voice Synthesis Toolkit},
  author={Yamamoto, Ryuichi and Yoneyama, Reo and Toda, Tomoki},
  journal={arXiv preprint arXiv:2210.15987},
  year={2022}
}
```

## Acknowledgements

- The inference implementation of uSFGAN was adapted from [chomeyama/HN-UnifiedSourceFilterGAN](https://github.com/chomeyama/HN-UnifiedSourceFilterGAN).
- The code for diffusion models was adapted from [DiffSinger](https://github.com/MoonInTheRiver/DiffSinger).
